# Credits

## Development team

- Jacopo Canton [@jcanton](https://github.com/jcanton)
- Guillaume Chauvat [@guillaumechauvat](https://github.com/guillaumechauvat)
- Nicolò Fabbiane [@nfabbiane](https://github.com/nfabbiane)
- Ashwin Vishnu Mohanan [@ashwinvis](https://github.com/ashwinvis)

## Contributors

- Pierre Augier [@paugier](https://github.com/paugier/)
- Simon Kern [@Simkern](https://github.com/Simkern/)
- Timofey Mukha [@timofeymukha](https://github.com/timofeymukha)
- Vitor Kleine
